%------------------------ identification ---------------------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{tagiis}[2015/05/14 v4.0]
%------------------------ initial code -----------------------------------------
\RequirePackage[leqno]{amsmath}
\RequirePackage{amssymb,amsthm}%,amsfonts}
\RequirePackage[final]{graphicx}
\RequirePackage{color,rotating,indentfirst,paralist}
\RequirePackage{textcomp}
\RequirePackage{xspace}
\RequirePackage{array,calc,ifthen,multicol}
%\RequirePackage{epic,eepicemu}
\RequirePackage{epstopdf}
\RequirePackage{enumerate,wrapfig}
\newboolean{twoup}
\newboolean{partchap}
%------------------------ declaration of options -------------------------------
\DeclareOption{twoup}{\setboolean{twoup}{true}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
%------------------------ execution of options ---------------------------------
\ProcessOptions\relax
\RequirePackage{txfonts,pscyr}
\renewcommand\rmdefault{ftm}
\RequirePackage[cp1251]{inputenc}
\RequirePackage[bulgarian]{babel}
%------------------------ package loading --------------------------------------
\LoadClass[11pt,a4paper,leqno,twoside]{book}% the real code
%------------------------ main code --------------------------------------------
\RequirePackage[text={28cc,42cc},centering]{geometry}
%\RequirePackage{fancyhdr}
\RequirePackage[perpage,stable,symbol]{footmisc}
\DefineFNsymbols*{tagi}{*{**}{***}{****}{*****}}
\setfnsymbol{tagi}
\RequirePackage[pagestyles,newlinetospace]{titlesec}
\RequirePackage{titletoc}
\RequirePackage{relsize,exscale}
\setcounter{secnumdepth}{3}
\RequirePackage{tocloft}
\RequirePackage[fit]{truncate}
%\RequirePackage[unicode,colorlinks,linkcolor=blue,citecolor=red]{hyperref}
%=====================================================================
%\textwidth      28cc
%\headwidth      25cc
%\textheight     42cc
\topmargin      20mm
\oddsidemargin  20mm
\evensidemargin 20mm
\marginparwidth  0pt
\marginparsep    0pt
\headheight      2cc
\headsep       1.5cc
\footskip        2cc
\parindent     1.5cc
\arraycolsep     2pt
\multlinegap     0pt
\unitlength      1mm
%\raggedbottom
\frenchspacing
\renewcommand{\arraystretch}{1.2}
\AtBeginDocument{\ifthenelse{\boolean{twoup}}%
           {\addtolength\oddsidemargin{5mm}%
            \addtolength\evensidemargin{-5mm}}{}}%
%\newcommand{\plotplus}[2]{\put(#1,#2){\makebox(0,0){\color{red}{$+$}}}}
%\newcommand{\plotminus}[2]{\put(#1,#2){\makebox(0,0){\color{red}{$-$}}}}
%\newcommand\red[1]{\color{red}{#1}}
%\newcommand\blue[1]{\color{blue}{#1}}
%=====================================================================
%                        Page Style
%=====================================================================
\newpagestyle{main}{%
\renewcommand{\makeheadrule}{%
\rule[-.8\baselineskip]{\linewidth}{0.4pt}}%
%\headrule
   \sethead[\thepage][\protect\truncate{25cc}{\chaptertitle}][]  % even
           {}{\protect\truncate{25cc}{\S~\thesection. \sectiontitle}}{\thepage}} % odd
\def\sctntitle{ }
\newpagestyle{prob}{%
\renewcommand{\makeheadrule}{%
\rule[-.8\baselineskip]{\linewidth}{0.4pt}}%
%\headrule
   \sethead[\thepage][\chaptertitle][]  % even
           {}{\sctntitle}{\thepage}} % odd
\newpagestyle{cont}{%
\renewcommand{\makeheadrule}{%
\rule[-.8\baselineskip]{\linewidth}{0.4pt}}%
%\headrule
   \sethead[\thepage][\contentsname][]  % even
           {}{\contentsname}{\thepage}} % odd
%\pagestyle{fancy}
%\fancyhead{}%
%\fancyfoot{}%
%\fancyhead[CE]{\slshape\truncate{\headwidth}{\nouppercase{\leftmark}}}
%\fancyhead[CO]{\slshape\truncate{\headwidth}{\nouppercase{\rightmark}}}
%\fancyhead[EL,OR]{\thepage}
%%\fancyfoot[ER,OL]{\today}
%%\renewcommand{\footrulewidth}{\headrulewidth}
%\fancypagestyle{first}{%
%\fancyhead{}%
%\fancyfoot[ER,OL]{\today}%
%\fancyfoot[EL,OR]{\thepage}%
%\renewcommand{\headrulewidth}{0pt}
%\renewcommand{\footrulewidth}{0.4pt}%
%}
%\renewcommand\chaptermark[1]{\markboth{#1}{}}
%=====================================================================
%                           Part  
%=====================================================================
\renewcommand\part{%
  \if@openright
    \cleardoublepage
  \else
    \clearpage
  \fi
  \thispagestyle{plain}%
  \if@twocolumn
    \onecolumn
    \@tempswatrue
  \else
    \@tempswafalse
  \fi
  %\null\vfil
  \secdef\@part\@spart}
\def\@part[#1]#2{\setboolean{partchap}{true}%
    \ifnum \c@secnumdepth >-2\relax
      \refstepcounter{part}%
      \addcontentsline{toc}{part}{\partname~\thepart\protect\\#1}%
    \else
      \addcontentsline{toc}{part}{#1}%
    \fi
    \markboth{}{}%
    {\centering
     %\interlinepenalty \@M
     \normalfont
     \ifnum \c@secnumdepth >-2\relax
       \large\bfseries \partname\nobreakspace\thepart
       \par
       \vskip 8\p@
     \fi
     \large \bfseries #2\par\vskip 8\p@}}
%=====================================================================
%                           Chapter  
%=====================================================================
\renewcommand\thechapter{\Roman{chapter}}
\renewcommand\chapter{%
\ifthenelse{\boolean{partchap}}{\relax\vspace*{3ex}}
%{\if@openright\cleardoublepage\else\clearpage\fi}
{\vspace{2ex}}
                    \setboolean{partchap}{false}
                    \thispagestyle{plain}%
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
\def\@makechapterhead#1{%
  %\vspace*{8\p@}%
  {\parindent \z@ \centering \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \bfseries \@chapapp\space \thechapter
        \par\nobreak
        \vskip 8\p@
      \fi
    \fi
    \interlinepenalty\@M
    \bfseries \uppercase{#1}\par\nobreak
    \vskip 8\p@
  }}
%=====================================================================
%                           Sections  
%=====================================================================
\titleformat{\section}[block]
{\normalfont\large\bfseries\boldmath\filcenter}
{\S\ \arabic{section}.}{0.5em}{}
\titleformat{\subsection}[block]
{\normalfont\itshape\bfseries\boldmath\filcenter}
{\Roman{subsection}.}{0.5em}{}
\titleformat{\subsubsection}[block]
{\normalfont\slshape\filcenter}
{\arabic{subsubsection}.}{0.5em}{}
\titlespacing*{\subsubsection}{0pt}
{3.25ex plus 1ex minus .2ex}{3.25ex plus .1ex}
\renewcommand\thesubsection{\Roman{subsection}}
%%%%%
\titlecontents{section}
[2.5em] % ie, 1.5em (chapter) + 2.3em
{}
{\contentslabel[\S~\thecontentslabel.]{2.5em}}
{\hspace*{-2.5em}}
{\titlerule*[1pc]{.}\contentspage}
%%%%%
\titlecontents{subsection}
[4.5em] % ie, 1.5em (chapter) + 2.3em
{}
{\contentslabel[\thecontentslabel.]{2em}}
{}
{\titlerule*[1pc]{.}\contentspage}
%%%%%
\titlecontents{part}
[1pc]
{\addvspace{1.5pc}%
\filcenter}
{\large}
{\large\bfseries}
{} % That is, without page number
[\addvspace{.5pc}]
%%%%%
\titlecontents{chapter}
[4pc]
{\addvspace{1pc}}%
{\contentsmargin{0pt}%
\bfseries
\makebox[0pt][r]{\large\chaptername~\thecontentslabel.\enspace}%
\large}
{\contentsmargin{0pt}%
\large}
{\titlerule*[1pc]{.}\contentspage}
%{\quad\thepage}
[\addvspace{.5pc}]
%=====================================================================
%                           Figures
%=====================================================================
\unitlength=1mm
\RequirePackage[font=small,labelsep=period,center,tableposition=top]
               {caption}
\AtBeginDocument{\renewcommand{\figurename}{.}}
%=====================================================================
%Useful abbreviations for multiletter commands. Their usage is optional!
%=====================================================================
\newcommand{\mc}{\multicolumn}
\newcommand{\cl}{\centerline}
\newcommand{\ol}{\overline}
\newcommand{\ds}{\displaystyle}
\newcommand{\la}{\langle}
\newcommand{\ra}{\rangle}
\newcommand{\bc}{\begin{center}}
\newcommand{\ec}{\end{center}}
\newcommand{\ba}{\begin{array}}
\newcommand{\ea}{\end{array}}
\newcommand{\bt}{\begin{tabular}}
\newcommand{\et}{\end{tabular}}
\newcommand{\beq}{\begin{equation}}
\newcommand{\eeq}{\end{equation}}
\newcommand{\bea}{\begin{eqnarray}}
\newcommand{\eea}{\end{eqnarray}}
\newcommand\ph{\hphantom}
%=====================================================================
%                        New commands
%=====================================================================
\newcommand{\up}[2]{\raisebox{#1}[0pt][0pt]{#2}}
\newcommand{\ga}{\alpha}
\newcommand{\gb}{\beta}
\newcommand{\gd}{\delta}
\newcommand{\gl}{\lambda}
\newcommand{\eps}{\varepsilon}
\newcommand{\gf}{\varphi}
\newcommand{\R}{\ensuremath{\mathbb{R}}}
\newcommand{\N}{\ensuremath{\mathbb{N}}}
\newcommand{\const}{\mathrm{const}}
\newcommand\mdot{\mathbin{.}}
\DeclareMathOperator{\sign}{sign}
\DeclareMathOperator{\arccotg}{arccotg}
\newcommand\te{.\,. }
\newcommand\enl{\enlargethispage}
\newcommand\lb{\linebreak}
\newcommand\pb{\pagebreak}
\let\angle=\sphericalangle
\newcommand\uup[2][1.2ex]{\raisebox{#1}[0pt][0pt]{#2}}
\newcommand\tup[2][c]{\bt{@{}#1@{}}#2\et}
\newcommand\dok{\textbf{.} }
\newcommand\ins{\emph{}. }
\newcommand\sol{\emph{}. }
\newcommand\question{\emph{}. }
\newcommand\ans{\emph{}. }
\newcommand\otg{. }
\newcommand\rd{\mathrm{d}}
\newcommand\upint{\mathchoice%
    {\mkern13mu\overline{\vphantom{\intop}\mkern7mu}\mkern-20mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
  \int}
\newcommand\lowint{\mkern3mu\underline{\vphantom{\intop}\mkern7mu}\mkern-10mu\int}
\newcommand\upiint{\mathchoice%
    {\mkern13mu\overline{\vphantom{\intop}\mkern20mu}\mkern-33mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
  \iint}
\newcommand\lowiint{\mkern3mu\underline{\vphantom{\intop}\mkern20mu}\mkern-23mu\iint}
\newcommand\upiiint{\mathchoice%
    {\mkern10mu\overline{\vphantom{\intop}\mkern30mu}\mkern-45mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
    {\mkern7mu\overline{\vphantom{\intop}\mkern7mu}\mkern-14mu}%
  \iiint}
\newcommand\lowiiint{\mkern3mu\underline{\vphantom{\intop}\mkern30mu}%
\mkern-33mu\iiint}
\newcommand\dx{\rd x}
\newcommand\dy{\rd y}
\newcommand\dz{\rd z}
\newcommand\dt{\rd t}
\DeclareMathOperator\cotg{cotg}
\newcommand\lint{\mathlarger{\int}}
\newcommand\llint{\mathlarger{\mathlarger{\int}}}
\newcommand\lllint{\mathlarger{\mathlarger{\mathlarger{\int}}}}
\newcommand\llllint{\mathlarger{\mathlarger{\mathlarger{\mathlarger{\int}}}}}
\newcommand\lllllint{\mathlarger{\mathlarger{\mathlarger{\mathlarger{\mathlarger{\int}}}}}}
%=====================================================================
\renewcommand{\topfraction}{.99}
\renewcommand{\bottomfraction}{.99}
\renewcommand{\textfraction}{.01}
%=====================================================================
%                        Theorems
%=====================================================================
\newtheoremstyle{bg}% name
  {0pt}%       Space above
  {0pt}%       Space below
  {}%          Body font
  {\parindent}%Indent amount (empty = no indent, \parindent = para indent)
  {}%          Thm head font
  {.}%         Punctuation after thm head
  { }%         Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%          Thm head spec (can be left empty, meaning `normal')
\theoremstyle{bg}
\newtheorem{pr}{}%\label{pr:3.1.1.1}
%
\newtheoremstyle{bgbf}% name
  {0pt}%       Space above
  {0pt}%       Space below
  {}%          Body font
  {\parindent}%Indent amount (empty = no indent, \parindent = para indent)
  {\bfseries}% Thm head font
  {.}%         Punctuation after thm head
  { }%         Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%          Thm head spec (can be left empty, meaning `normal')
\theoremstyle{bgbf}
\newtheorem*{dfn}{}
%
\newtheoremstyle{bgit}% name
  {0pt}%       Space above
  {0pt}%       Space below
  {}%          Body font
  {\parindent}%Indent amount (empty = no indent, \parindent = para indent)
  {\itshape}%  Thm head font
  {.}%         Punctuation after thm head
  { }%         Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%          Thm head spec (can be left empty, meaning `normal')
\theoremstyle{bgit}
\newtheorem{note}{}%\label{note:1.2.3.4}
\newtheorem*{Note}{}
\newtheorem*{gen}{}
\newtheorem{Cor}{}%\label{cor:1.2.3.4}
\newtheorem{EX}{}%
%
\newtheoremstyle{bgem}% name
  {0pt}%       Space above
  {0pt}%       Space below
  {\itshape}%          Body font
  {\parindent}%Indent amount (empty = no indent, \parindent = para indent)
  {\bfseries}%  Thm head font
  {.}%         Punctuation after thm head
  { }%         Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%          Thm head spec (can be left empty, meaning `normal')
\theoremstyle{bgem}
\newtheorem*{dfnem}{}
\newtheorem*{thm}{}
\newtheorem{Thm}{}%\label{thm:1.2.3.4}
\newtheorem{lemma}{}%\label{lemma:1.2.3.4}
%
\newtheoremstyle{bgfns}% name
  {1ex}%       Space above
  {1ex}%       Space below
  {\normalfont}%Body font
  {\parindent}%Indent amount (empty = no indent, \parindent = para indent)
  {\itshape}%  Thm head font
  {.}%         Punctuation after thm head
  { }%         Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%          Thm head spec (can be left empty, meaning `normal')
\theoremstyle{bgfns}
\newtheorem{ex}{}%\label{ex:1.2.3.4}
\newtheorem*{Ex}{}%
\newtheoremstyle{bgembf}% name
  {0pt}%       Space above
  {0pt}%       Space below
  {\itshape}%          Body font
  {\parindent}%Indent amount (empty = no indent, \parindent = para indent)
  {\bfseries\itshape}%  Thm head font
  {.}%         Punctuation after thm head
  { }%         Space after thm head: " " = normal interword space;
        %       \newline = linebreak
  {}%          Thm head spec (can be left empty, meaning `normal')
\theoremstyle{bgembf}
\newtheorem*{cor}{}
\newtheorem*{thm11}{ }
\newtheorem*{Peanothm}{  }
%
\newenvironment{examples}{\par\smallskip\begin{footnotesize}\emph{.}}
                         {\par\end{footnotesize}}
\newenvironment{problems}[1][]
               {\par\bigskip\cl{\textbf{#1}}%\markright{#1}
                \def\sctntitle{#1}
                \ifthenelse{\equal{\sctntitle}{}}%
                           {\relax}%
                           {\pagestyle{prob}}%
                \setcounter{pr}{0}\setcounter{equation}{0}\par\bigskip}%
%                \addcontentsline{toc}{section}{\hskip\cftsecnumwidth\,#1}}%
               {\par}%
\newenvironment{ena}{\begin{enumerate}[\indent a)]}{\end{enumerate}}
%=====================================================================
\renewcommand{\cftsecpresnum}{\S~}
\renewcommand{\cftchappresnum}{\chaptername~}
\settowidth{\cftchapnumwidth}{\chaptername~IV}
\cftpagenumbersoff{part}
\graphicspath{{./Figs/}}
\renewcommand\thefigure{\arabic{figure}}
\def\@removefromreset#1#2{\let\@tempb\@elt
   \expandafter\let\expandafter\@tempa\csname c@#1\endcsname
   \def\@elt##1{\expandafter\ifx\csname c@##1\endcsname\@tempa\else
         \noexpand\@elt{##1}\fi}%
   \expandafter\edef\csname cl@#2\endcsname{\csname cl@#2\endcsname}%
   \let\@elt\@tempb}
\@removefromreset{figure}{chapter}
\@removefromreset{section}{chapter}
%\@addtoreset{chapter}{part}
\@addtoreset{equation}{section}
\@addtoreset{pr}{section}
\@addtoreset{ex}{section}
\@addtoreset{note}{section}
\@addtoreset{lemma}{section}
\@addtoreset{Thm}{section}
\renewcommand\theequation{\arabic{equation}}
\renewcommand\thesection{\arabic{section}}
\renewcommand\thefigure{\arabic{figure}}
\pagestyle{main}
\endinput

